import { useEffect, useMemo, useRef, useState } from "react";
import { Graph } from "@antv/x6";
import { History } from "@antv/x6-plugin-history";
import { Transform } from "@antv/x6-plugin-transform";
import "@/components/TableNode";
export default function erModel() {
  const graphRef = useRef<Graph>();
  const [graph, setGraph] = useState<Graph>();
  const initGraph = (container: HTMLElement) => {
    const instance = new Graph({
      container,
      width: document.documentElement.clientWidth,
      height: document.documentElement.clientHeight,
      autoResize: true,
      async: false,
      mousewheel: {
        enabled: true,
        modifiers: "ctrl",
        minScale: 0.2,
        maxScale: 2,
      },
      connecting: {
        connectionPoint: "anchor",
      },
      grid: {
        visible: true,
      },
      background: {
        color: "#F2F7FA",
      },
    });

    instance.use(new History());
    instance.use(new Transform());

    instance.addNode({
      shape: "rect",
      x: 100,
      y: 100,
      width: 100,
      height: 100,
      attrs: {
        body: {
          stroke: "#8f8f8f",
          strokeWidth: 1,
          fill: "#fff",
        },
      },
    });

    instance.addNode({
      shape: "table-node",
      x: 300,
      y: 100,
      width: 200,
      height: 200,
    })

    graphRef.current = instance;
  };

  useEffect(() => {
    if (graphRef.current) {
      console.log(1111, graphRef.current)
      setGraph(graphRef.current);
    }
  }, [graphRef.current]);

  return {
    initGraph,
    graph,
  };
}
